@@ -43,17 +43,12 @@ typedef void (*TrackerStatementCallback) (gint         graph_id,
                                           const gchar *object,
                                           GPtrArray   *rdf_types,
                                           gpointer     user_data);
-typedef void (*TrackerCommitCallback)    (gpointer     user_data);
-typedef void (*TrackerBusyCallback)      (const gchar *status,
-                                          gdouble      progress,
+typedef void (*TrackerCommitCallback)    (gboolean     start_timer,
                                           gpointer     user_data);
 
 GQuark   tracker_data_error_quark                   (void);
 
 /* Metadata */
-void     tracker_data_delete_resource_description   (const gchar               *graph,
-                                                     const gchar               *url,
-                                                     GError                   **error);
 void     tracker_data_delete_statement              (const gchar               *graph,
                                                      const gchar               *subject,
                                                      const gchar               *predicate,
@@ -74,15 +69,21 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
                                                      const gchar               *predicate,
                                                      const gchar               *object,
                                                      GError                   **error);
+void     tracker_data_update_statement              (const gchar               *graph,
+                                                     const gchar               *subject,
+                                                     const gchar               *predicate,
+                                                     const gchar               *object,
+                                                     GError                   **error);
 void     tracker_data_begin_transaction             (GError                   **error);
+void     tracker_data_begin_ontology_transaction    (GError                   **error);
 void     tracker_data_begin_transaction_for_replay  (time_t                     time,
                                                      GError                   **error);
 void     tracker_data_commit_transaction            (GError                   **error);
-void     tracker_data_notify_transaction            (void);
+void     tracker_data_notify_transaction            (gboolean                   start_timer);
 void     tracker_data_rollback_transaction          (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
                                                      GError                   **error);
-GPtrArray *
+GVariant *
          tracker_data_update_sparql_blank           (const gchar               *update,
                                                      GError                   **error);
 void     tracker_data_update_buffer_flush           (GError                   **error);
@@ -91,12 +92,10 @@ void     tracker_data_load_turtle_file              (GFile                     *
                                                      GError                   **error);
 
 void     tracker_data_sync                          (void);
-void     tracker_data_replay_journal                (GHashTable                *classes,
-                                                     GHashTable                *properties,
-                                                     GHashTable                *id_uri_map,
-                                                     TrackerBusyCallback        busy_callback,
+void     tracker_data_replay_journal                (TrackerBusyCallback        busy_callback,
                                                      gpointer                   busy_user_data,
-                                                     const gchar               *busy_status);
+                                                     const gchar               *busy_status,
+                                                     GError                   **error);
 
 /* Calling back */
 void     tracker_data_add_insert_statement_callback      (TrackerStatementCallback   callback,
