@@ -31,12 +31,13 @@
 #define TEST_TIMEOUT 5 /* seconds */
 
 typedef enum {
-	MONITOR_SIGNAL_NONE            = 0,
-	MONITOR_SIGNAL_ITEM_CREATED    = 1 << 0,
-	MONITOR_SIGNAL_ITEM_UPDATED    = 1 << 1,
-	MONITOR_SIGNAL_ITEM_DELETED    = 1 << 2,
-	MONITOR_SIGNAL_ITEM_MOVED_FROM = 1 << 3,
-	MONITOR_SIGNAL_ITEM_MOVED_TO   = 1 << 4
+	MONITOR_SIGNAL_NONE                   = 0,
+	MONITOR_SIGNAL_ITEM_CREATED           = 1 << 0,
+	MONITOR_SIGNAL_ITEM_UPDATED           = 1 << 1,
+	MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED = 1 << 2,
+	MONITOR_SIGNAL_ITEM_DELETED           = 1 << 3,
+	MONITOR_SIGNAL_ITEM_MOVED_FROM        = 1 << 4,
+	MONITOR_SIGNAL_ITEM_MOVED_TO          = 1 << 5
 } MonitorSignal;
 
 /* Fixture object type */
@@ -118,6 +119,29 @@ test_monitor_events_updated_cb (TrackerMonitor *monitor,
 	           MONITOR_SIGNAL_ITEM_UPDATED);
 }
 
+static void
+test_monitor_events_attribute_updated_cb (TrackerMonitor *monitor,
+                                          GFile          *file,
+                                          gboolean        is_directory,
+                                          gpointer        user_data)
+{
+	gchar *path;
+
+	g_assert (file != NULL);
+	path = g_file_get_path (file);
+	g_assert (path != NULL);
+
+	g_debug ("***** '%s' (%s) (ATRIBUTE UPDATED)",
+	         path,
+	         is_directory ? "DIR" : "FILE");
+
+	g_free (path);
+
+	add_event ((GHashTable *) user_data,
+	           file,
+	           MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED);
+}
+
 static void
 test_monitor_events_deleted_cb (TrackerMonitor *monitor,
                                 GFile          *file,
@@ -196,6 +220,9 @@ test_monitor_common_setup (TrackerMonitorTestFixture *fixture,
 	g_signal_connect (fixture->monitor, "item-updated",
 	                  G_CALLBACK (test_monitor_events_updated_cb),
 	                  fixture->events);
+	g_signal_connect (fixture->monitor, "item-attribute-updated",
+	                  G_CALLBACK (test_monitor_events_attribute_updated_cb),
+	                  fixture->events);
 	g_signal_connect (fixture->monitor, "item-deleted",
 	                  G_CALLBACK (test_monitor_events_deleted_cb),
 	                  fixture->events);
@@ -302,6 +329,21 @@ set_file_contents (const gchar  *directory,
 	g_free (file_path);
 }
 
+static void
+set_file_permissions (const gchar  *directory,
+                      const gchar  *filename,
+                      gint          permissions)
+{
+	gchar *file_path;
+
+	g_assert (directory != NULL);
+	g_assert (filename != NULL);
+
+	file_path = g_build_filename (directory, filename, NULL);
+	g_assert_cmpint (g_chmod (file_path, permissions), ==, 0);
+	g_free (file_path);
+}
+
 static void
 print_file_events_cb (gpointer key,
                       gpointer value,
@@ -316,14 +358,16 @@ print_file_events_cb (gpointer key,
 	uri = g_file_get_uri (file);
 
 	g_print ("Signals received for '%s': \n"
-	         "   CREATED:    %s\n"
-	         "   UPDATED:    %s\n"
-	         "   DELETED:    %s\n"
-	         "   MOVED_FROM: %s\n"
-	         "   MOVED_TO:   %s\n",
+	         "   CREATED:           %s\n"
+	         "   UPDATED:           %s\n"
+	         "   ATTRIBUTE UPDATED: %s\n"
+	         "   DELETED:           %s\n"
+	         "   MOVED_FROM:        %s\n"
+	         "   MOVED_TO:          %s\n",
 	         uri,
 	         events & MONITOR_SIGNAL_ITEM_CREATED ? "yes" : "no",
 	         events & MONITOR_SIGNAL_ITEM_UPDATED ? "yes" : "no",
+	         events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED ? "yes" : "no",
 	         events & MONITOR_SIGNAL_ITEM_DELETED ? "yes" : "no",
 	         events & MONITOR_SIGNAL_ITEM_MOVED_FROM ? "yes" : "no",
 	         events & MONITOR_SIGNAL_ITEM_MOVED_TO ? "yes" : "no");
@@ -378,11 +422,15 @@ test_monitor_file_event_created (TrackerMonitorTestFixture *fixture,
 	/* Fail if we didn't get the CREATE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), >, 0);
 
-	/* Fail if we got a MOVE or DELETE signal (update may actually happen) */
+	/* Fail if we got a MOVE or DELETE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 
+	/* A single CREATED event should now never trigger an UPDATED event */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+
 	/* Cleanup environment */
 	tracker_monitor_set_enabled (fixture->monitor, FALSE);
 
@@ -434,6 +482,53 @@ test_monitor_file_event_updated (TrackerMonitorTestFixture *fixture,
 	g_object_unref (test_file);
 }
 
+static void
+test_monitor_file_event_attribute_updated (TrackerMonitorTestFixture *fixture,
+                                           gconstpointer              data)
+{
+	GFile *test_file;
+	guint file_events;
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &test_file);
+	g_assert (test_file != NULL);
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Now, trigger attribute update of the already created file */
+	set_file_permissions (fixture->monitored_directory,
+	                      "created.txt",
+	                      S_IRWXU);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (test_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, test_file));
+
+	/* Fail if we didn't get the ATTRIBUTE UPDATE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), >, 0);
+
+	/* Fail if we got a UPDATE, CREATE, MOVE or DELETE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+
+	/* Remove the test file */
+	g_assert_cmpint (g_file_delete (test_file, NULL, NULL), ==, TRUE);
+	g_object_unref (test_file);
+}
+
 static void
 test_monitor_file_event_deleted (TrackerMonitorTestFixture *fixture,
                                  gconstpointer              data)
@@ -466,6 +561,7 @@ test_monitor_file_event_deleted (TrackerMonitorTestFixture *fixture,
 	/* Fail if we got a CREATE, UDPATE or MOVE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -516,6 +612,7 @@ test_monitor_file_event_moved_to_monitored (TrackerMonitorTestFixture *fixture,
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 
@@ -579,6 +676,7 @@ test_monitor_file_event_moved_to_not_monitored (TrackerMonitorTestFixture *fixtu
 	/* Fail if we got a CREATE, UPDATE or MOVE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 
@@ -587,6 +685,7 @@ test_monitor_file_event_moved_to_not_monitored (TrackerMonitorTestFixture *fixtu
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -640,6 +739,7 @@ test_monitor_file_event_moved_from_not_monitored (TrackerMonitorTestFixture *fix
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -651,6 +751,7 @@ test_monitor_file_event_moved_from_not_monitored (TrackerMonitorTestFixture *fix
 	/* Fail if we got a DELETE, UPDATE or MOVE signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 
@@ -663,6 +764,447 @@ test_monitor_file_event_moved_from_not_monitored (TrackerMonitorTestFixture *fix
 	g_free (dest_path);
 }
 
+/* ----------------------------- FILE EVENT BLACKLISTING TESTS -------------- */
+
+static void
+test_monitor_file_event_blacklisting_created_updated (TrackerMonitorTestFixture *fixture,
+                                                      gconstpointer              data)
+{
+	GFile *test_file;
+	guint file_events;
+	guint i;
+
+	/*
+	 * Event merging:
+	 *  CREATED + N*UPDATED = CREATED
+	 */
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &test_file);
+	g_assert (test_file != NULL);
+
+	/* Now, trigger 10 updates of the already created file.
+	 * This will generate 10 CHANGED+CHANGES_DONE_HINT events in GIO
+	 */
+	for (i=0; i<10; i++) {
+		set_file_contents (fixture->monitored_directory, "created.txt", "barrrr", NULL);
+	}
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (test_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, test_file));
+
+	/* Fail if we didn't get the CREATED signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), >, 0);
+
+	/* Fail if we got a UPDATE, MOVE or DELETE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+
+	/* Remove the test file */
+	g_assert_cmpint (g_file_delete (test_file, NULL, NULL), ==, TRUE);
+	g_object_unref (test_file);
+}
+
+static void
+test_monitor_file_event_blacklisting_created_deleted (TrackerMonitorTestFixture *fixture,
+                                                      gconstpointer              data)
+{
+	GFile *test_file;
+	guint file_events;
+
+	/*
+	 * Event merging:
+	 *  CREATED + DELETED = <nothing>
+	 */
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &test_file);
+	g_assert (test_file != NULL);
+
+	/* Remove the test file */
+	g_assert_cmpint (g_file_delete (test_file, NULL, NULL), ==, TRUE);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (test_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, test_file));
+
+	/* Fail if we got any signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+
+	g_object_unref (test_file);
+}
+
+static void
+test_monitor_file_event_blacklisting_created_updated_deleted (TrackerMonitorTestFixture *fixture,
+                                                              gconstpointer              data)
+{
+	GFile *test_file;
+	guint file_events;
+	guint i;
+
+	/*
+	 * Event merging:
+	 *  CREATED + N*UPDATED + DELETED = <nothing>
+	 */
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &test_file);
+	g_assert (test_file != NULL);
+
+	/* Now, trigger 10 updates of the already created file.
+	 * This will generate 10 CHANGED+CHANGES_DONE_HINT events in GIO
+	 */
+	for (i=0; i<10; i++) {
+		set_file_contents (fixture->monitored_directory, "created.txt", "barrrr", NULL);
+	}
+
+	/* Remove the test file */
+	g_assert_cmpint (g_file_delete (test_file, NULL, NULL), ==, TRUE);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (test_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, test_file));
+
+	/* Fail if we got any signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+
+	g_object_unref (test_file);
+}
+
+static void
+test_monitor_file_event_blacklisting_created_moved (TrackerMonitorTestFixture *fixture,
+                                                    gconstpointer              data)
+{
+	GFile *source_file;
+	gchar *source_path;
+	GFile *dest_file;
+	gchar *dest_path;
+	guint file_events;
+
+	/*
+	 * Event merging:
+	 *  CREATED(A) + MOVED(A->B) = CREATED(B)
+	 */
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &source_file);
+	g_assert (source_file != NULL);
+
+	/* Now, rename the file */
+	source_path = g_file_get_path (source_file);
+	dest_path = g_build_filename (fixture->monitored_directory, "renamed.txt", NULL);
+	dest_file = g_file_new_for_path (dest_path);
+	g_assert (dest_file != NULL);
+
+	g_assert_cmpint (g_rename (source_path, dest_path), ==, 0);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (source_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (dest_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the source file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, source_file));
+
+	/* Fail if we got ANY event */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Get events in the dest file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, dest_file));
+
+	/* Fail if we didn't get the CREATED signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), >, 0);
+
+	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+	g_assert_cmpint (g_file_delete (dest_file, NULL, NULL), ==, TRUE);
+	g_object_unref (source_file);
+	g_object_unref (dest_file);
+	g_free (source_path);
+	g_free (dest_path);
+}
+
+static void
+test_monitor_file_event_blacklisting_updated_deleted (TrackerMonitorTestFixture *fixture,
+                                                      gconstpointer              data)
+{
+	GFile *test_file;
+	guint file_events;
+	guint i;
+
+	/*
+	 * Event merging:
+	 *  N*UPDATED + DELETED = DELETED
+	 */
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &test_file);
+	g_assert (test_file != NULL);
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Now, trigger 10 updates of the already created file.
+	 * This will generate 10 CHANGED+CHANGES_DONE_HINT events in GIO
+	 */
+	for (i=0; i<10; i++) {
+		set_file_contents (fixture->monitored_directory, "created.txt", "barrrr", NULL);
+	}
+
+	/* Remove the test file */
+	g_assert_cmpint (g_file_delete (test_file, NULL, NULL), ==, TRUE);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (test_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, test_file));
+
+	/* Fail if we didn't get the DELETED signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), >, 0);
+
+	/* Fail if we got any signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+
+	g_object_unref (test_file);
+}
+
+static void
+test_monitor_file_event_blacklisting_updated_moved (TrackerMonitorTestFixture *fixture,
+                                                    gconstpointer              data)
+{
+	GFile *source_file;
+	gchar *source_path;
+	GFile *dest_file;
+	gchar *dest_path;
+	guint file_events;
+
+	/*
+	 * Event merging:
+	 *  UPDATED(A) + MOVED(A->B) = MOVED(A->B) + UPDATED(B)
+	 */
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &source_file);
+	g_assert (source_file != NULL);
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Update the file */
+	set_file_contents (fixture->monitored_directory, "created.txt", "barrrr", NULL);
+
+	/* Now, rename the file */
+	source_path = g_file_get_path (source_file);
+	dest_path = g_build_filename (fixture->monitored_directory, "renamed.txt", NULL);
+	dest_file = g_file_new_for_path (dest_path);
+	g_assert (dest_file != NULL);
+
+	g_assert_cmpint (g_rename (source_path, dest_path), ==, 0);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (source_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (dest_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the source file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, source_file));
+
+	/* Fail if we didn't get the MOVED_FROM event */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), >, 0);
+
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Get events in the dest file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, dest_file));
+
+	/* Fail if we didn't get the MOVED_TO and UPDATED signals */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), >, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), >, 0);
+
+	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+	g_assert_cmpint (g_file_delete (dest_file, NULL, NULL), ==, TRUE);
+	g_object_unref (source_file);
+	g_object_unref (dest_file);
+	g_free (source_path);
+	g_free (dest_path);
+}
+
+static void
+test_monitor_file_event_blacklisting_attribute_updated_moved (TrackerMonitorTestFixture *fixture,
+                                                              gconstpointer              data)
+{
+	GFile *source_file;
+	gchar *source_path;
+	GFile *dest_file;
+	gchar *dest_path;
+	guint file_events;
+
+	/*
+	 * Event merging:
+	 *  ATTRIBUTE_UPDATED(A) + MOVED(A->B) = MOVED(A->B) + UPDATED(B)
+	 */
+
+	/* Create file to test with, before setting up environment */
+	set_file_contents (fixture->monitored_directory, "created.txt", "foo", &source_file);
+	g_assert (source_file != NULL);
+
+	/* Set up environment */
+	tracker_monitor_set_enabled (fixture->monitor, TRUE);
+
+	/* Now, trigger attribute update of the already created file */
+	set_file_permissions (fixture->monitored_directory,
+	                      "created.txt",
+	                      S_IRWXU);
+	set_file_contents (fixture->monitored_directory, "created.txt", "barrrr", NULL);
+
+	/* Now, rename the file */
+	source_path = g_file_get_path (source_file);
+	dest_path = g_build_filename (fixture->monitored_directory, "renamed.txt", NULL);
+	dest_file = g_file_new_for_path (dest_path);
+	g_assert (dest_file != NULL);
+
+	g_assert_cmpint (g_rename (source_path, dest_path), ==, 0);
+
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (source_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+	g_hash_table_insert (fixture->events,
+	                     g_object_ref (dest_file),
+	                     GUINT_TO_POINTER (MONITOR_SIGNAL_NONE));
+
+	/* Wait for events */
+	events_wait (fixture);
+
+	/* Get events in the source file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, source_file));
+
+	/* Fail if we didn't get the MOVED_FROM event */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), >, 0);
+
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Get events in the dest file */
+	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, dest_file));
+
+	/* Fail if we didn't get the UPDATED signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), >, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), >, 0);
+
+	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE signal */
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
+
+	/* Cleanup environment */
+	tracker_monitor_set_enabled (fixture->monitor, FALSE);
+	g_assert_cmpint (g_file_delete (dest_file, NULL, NULL), ==, TRUE);
+	g_object_unref (source_file);
+	g_object_unref (dest_file);
+	g_free (source_path);
+	g_free (dest_path);
+}
+
 /* ----------------------------- DIRECTORY EVENT TESTS --------------------------------- */
 
 static void
@@ -741,6 +1283,7 @@ test_monitor_directory_event_deleted (TrackerMonitorTestFixture *fixture,
 	/* Fail if we got a CREATEd, UPDATED, MOVED_FROM or MOVED_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -816,6 +1359,7 @@ test_monitor_directory_event_moved_to_monitored (TrackerMonitorTestFixture *fixt
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -833,6 +1377,7 @@ test_monitor_directory_event_moved_to_monitored (TrackerMonitorTestFixture *fixt
 	/* Fail if we got ANY signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -842,6 +1387,7 @@ test_monitor_directory_event_moved_to_monitored (TrackerMonitorTestFixture *fixt
 	/* Fail if we got ANY signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -849,8 +1395,11 @@ test_monitor_directory_event_moved_to_monitored (TrackerMonitorTestFixture *fixt
 
 	/* Cleanup environment */
 	tracker_monitor_set_enabled (fixture->monitor, FALSE);
-	/* Note that monitor is now in dest_dir */
-	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), ==, TRUE);
+	/* Since tracker 0.9.33, monitors are NOT moved to the new location directly when the
+	 * directory is moved, that is done by the upper layers.
+	 * Note that monitor is now in dest_dir */
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, source_dir), ==, TRUE);
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), !=, TRUE);
 	g_assert_cmpint (g_file_delete (file_in_dest_dir, NULL, NULL), ==, TRUE);
 	g_assert_cmpint (g_file_delete (dest_dir, NULL, NULL), ==, TRUE);
 	g_object_unref (source_dir);
@@ -930,6 +1479,7 @@ test_monitor_directory_event_moved_to_monitored_after_file_create (TrackerMonito
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -946,6 +1496,7 @@ test_monitor_directory_event_moved_to_monitored_after_file_create (TrackerMonito
 	file_events = GPOINTER_TO_UINT (g_hash_table_lookup (fixture->events, file_in_source_dir));
 	/* Fail if we got ANY signal != CREATED (we created the file while monitoring) */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -955,6 +1506,7 @@ test_monitor_directory_event_moved_to_monitored_after_file_create (TrackerMonito
 	/* Fail if we got ANY signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -962,8 +1514,11 @@ test_monitor_directory_event_moved_to_monitored_after_file_create (TrackerMonito
 
 	/* Cleanup environment */
 	tracker_monitor_set_enabled (fixture->monitor, FALSE);
-	/* Note that monitor is now in dest_dir */
-	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), ==, TRUE);
+	/* Since tracker 0.9.33, monitors are NOT moved to the new location directly when the
+	 * directory is moved, that is done by the upper layers.
+	 * Note that monitor is now in dest_dir */
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, source_dir), ==, TRUE);
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), !=, TRUE);
 	g_assert_cmpint (g_file_delete (file_in_dest_dir, NULL, NULL), ==, TRUE);
 	g_assert_cmpint (g_file_delete (dest_dir, NULL, NULL), ==, TRUE);
 	g_object_unref (source_dir);
@@ -1046,6 +1601,7 @@ test_monitor_directory_event_moved_to_monitored_after_file_update (TrackerMonito
 	/* Fail if we got a CREATE, UPDATE, DELETE or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -1073,6 +1629,7 @@ test_monitor_directory_event_moved_to_monitored_after_file_update (TrackerMonito
 	/* Fail if we got ANY signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
@@ -1080,8 +1637,11 @@ test_monitor_directory_event_moved_to_monitored_after_file_update (TrackerMonito
 
 	/* Cleanup environment */
 	tracker_monitor_set_enabled (fixture->monitor, FALSE);
-	/* Note that monitor is now in dest_dir */
-	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), ==, TRUE);
+	/* Since tracker 0.9.33, monitors are NOT moved to the new location directly when the
+	 * directory is moved, that is done by the upper layers.
+	 * Note that monitor is now in dest_dir */
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, source_dir), ==, TRUE);
+	g_assert_cmpint (tracker_monitor_remove (fixture->monitor, dest_dir), !=, TRUE);
 	g_assert_cmpint (g_file_delete (file_in_dest_dir, NULL, NULL), ==, TRUE);
 	g_assert_cmpint (g_file_delete (dest_dir, NULL, NULL), ==, TRUE);
 	g_object_unref (source_dir);
@@ -1137,6 +1697,7 @@ test_monitor_directory_event_moved_to_not_monitored (TrackerMonitorTestFixture *
 	/* Fail if we got a CREATE, UPDATE, MOVE_FROM or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 
@@ -1145,6 +1706,7 @@ test_monitor_directory_event_moved_to_not_monitored (TrackerMonitorTestFixture *
 	/* Fail if we got any signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
@@ -1200,6 +1762,7 @@ test_monitor_directory_event_moved_from_not_monitored (TrackerMonitorTestFixture
 	/* Fail if we got any signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
@@ -1210,6 +1773,7 @@ test_monitor_directory_event_moved_from_not_monitored (TrackerMonitorTestFixture
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_CREATED), >, 0);
 	/* Fail if we got a CREATE, UPDATE, MOVE_FROM or MOVE_TO signal */
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_UPDATED), ==, 0);
+	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_ATTRIBUTE_UPDATED), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_FROM), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_MOVED_TO), ==, 0);
 	g_assert_cmpuint ((file_events & MONITOR_SIGNAL_ITEM_DELETED), ==, 0);
@@ -1333,6 +1897,12 @@ main (gint    argc,
 	            test_monitor_common_setup,
 	            test_monitor_file_event_updated,
 	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/attribute-updated",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_attribute_updated,
+	            test_monitor_common_teardown);
 	g_test_add ("/libtracker-miner/tracker-monitor/file-event/deleted",
 	            TrackerMonitorTestFixture,
 	            NULL,
@@ -1358,6 +1928,50 @@ main (gint    argc,
 	            test_monitor_file_event_moved_from_not_monitored,
 	            test_monitor_common_teardown);
 
+	/* File event blacklisting tests */
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/created-updated",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_created_updated,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/created-deleted",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_created_deleted,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/created-updated-deleted",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_created_updated_deleted,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/created-moved",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_created_moved,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/updated-deleted",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_updated_deleted,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/updated-moved",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_updated_moved,
+	            test_monitor_common_teardown);
+	g_test_add ("/libtracker-miner/tracker-monitor/file-event/blacklisting/attribute-updated-moved",
+	            TrackerMonitorTestFixture,
+	            NULL,
+	            test_monitor_common_setup,
+	            test_monitor_file_event_blacklisting_attribute_updated_moved,
+	            test_monitor_common_teardown);
+
 	/* Directory Event tests */
 	g_test_add ("/libtracker-miner/tracker-monitor/directory-event/created",
 	            TrackerMonitorTestFixture,
